@@ -11,7 +11,7 @@
 #'             
 #' @details Permutation tests are non-parametric tests 
 #'          that do not assume normally-distributed errors.
-#'          See \url{http://rcompanion.org/rcompanion/d_06a.html} for
+#'          See \url{http://rcompanion.org/handbook/K_02.html} for
 #'          futher discussion of this test.
 #' 
 #'          The \code{pairwisePermutationTest} function
@@ -69,9 +69,7 @@ pairwisePermutationMatrix =
      Datay = subset(d, g==unique(g)[j])
      Dataz = rbind(Datax, Datay)
      Dataz$g2 = factor(Dataz$g)
-     z = independence_test(x ~ g2, data=Dataz,
-                           distribution = "asymptotic"
-                           )                  
+     z = independence_test(x ~ g2, data=Dataz, ...)                  
    Y[i,j] = signif(pvalue(z), digits = 4)
    } 
    }
