@@ -21,7 +21,7 @@
 #'                                                                                              
 #'           
 #' @author Salvatore Mangiafico, \email{mangiafico@njaes.rutgers.edu}
-#' @references \url{http://rcompanion.org/rcompanion/d_06a.html}
+#' @references \url{http://rcompanion.org/handbook/K_02.html}
 #' @seealso \code{\link{pairwisePermutationMatrix}}
 #' @concept permutation nonparametric post-hoc one-way
 #' @return A dataframe of the groups being compared, the p-values,
@@ -47,7 +47,7 @@ pairwisePermutationTest =
   N = n*(n-1)/2
   d = data.frame(x = x, g = g)
   Z = data.frame(Comparison=rep("A", N),
-                 W=rep(NA, N),
+                 Stat=rep(NA, N),
                  p.value=rep(NA, N),
                  p.adjust=rep(NA, N),
                  stringsAsFactors=FALSE)
@@ -62,9 +62,7 @@ pairwisePermutationTest =
      Datay = subset(d, g==unique(g)[j])
      Dataz = rbind(Datax, Datay)
      Dataz$g2 = factor(Dataz$g)
-     z = independence_test(x ~ g2, data=Dataz,
-                           distribution = "asymptotic", ...
-                           )
+     z = independence_test(x ~ g2, data=Dataz, ...)
      P = signif(pvalue(z), digits=4)
      S = signif(statistic (z), digits=4)
      P.adjust = NA                       
